==> Admin%20panel%20new%20install%20V7.8.zip: resources/views/admin-views/product/partials/_variant-combinations.blade.php <==
@if(count($combinations[0]) > 0)
    <table class="table table-bordered">
        <thead>
        <tr>
            <td class="text-center">
                <label for="" class="control-label">{{ translate('Variant') }}</label>
            </td>
            <td class="text-center">
                <label for="" class="control-label">{{ translate('Variant Price') }}</label>
            </td>
            <td class="text-center">
                <label for="" class="control-label">{{ translate('Variant Stock') }}</label>
            </td>
        </tr>
        </thead>
        <tbody>

        @foreach ($combinations as $key => $combination)
            @php
                $str = '';
                foreach ($combination as $key => $item){
                    if($key > 0 ){
                        $str .= '-'.str_replace(' ', '', $item);
                    }
                    else{
                        $str .= str_replace(' ', '', $item);
                    }
                }
            @endphp
            @if(strlen($str) > 0)
                <tr>
                    <td>
                        <label for="" class="control-label">{{ $str }}</label>
                    </td>
                    <td>
                        <input type="number" name="price_{{ $str }}" value="{{ $price }}" min="0" step="0.01"
                               class="form-control" >
                        <span class="error-text" data-error="price_{{ $str }}"></span>
                    </td>
                    <td>
                        <input type="number" name="stock_{{ $str }}" value="0" min="0" max="1000000"
                               class="form-control" onkeyup="update_qty()" >
                        <span class="error-text" data-error="stock_{{ $str }}"></span>
                    </td>
                </tr>
            @endif
        @endforeach
        </tbody>
    </table>
@endif

==> Admin%20panel%20new%20install%20V8.0.zip: resources/views/admin-views/product/partials/_variant-combinations.blade.php <==
@if(count($combinations[0]) > 0)
    <table class="table table-bordered">
        <thead>
        <tr>
            <td class="text-center">
                <label for="" class="control-label">{{ translate('Variant') }}</label>
            </td>
            <td class="text-center">
                <label for="" class="control-label">{{ translate('Variant Price') }}</label>
            </td>
            <td class="text-center">
                <label for="" class="control-label">{{ translate('Variant Stock') }}</label>
            </td>
        </tr>
        </thead>
        <tbody>

        @foreach ($combinations as $key => $combination)
            @php
                $str = '';
                foreach ($combination as $key => $item){
                    if($key > 0 ){
                        $str .= '-'.str_replace(' ', '', $item);
                    }
                    else{
                        $str .= str_replace(' ', '', $item);
                    }
                }
                 $matchedVariation = collect($productVariations ?? [])->firstWhere('type', $str);
            @endphp
            @if(strlen($str) > 0)
                <tr>
                    <td>
                        <label for="" class="control-label">{{ $str }}</label>
                    </td>
                    <td>
                        <input type="number" name="price_{{ $str }}" value="{{ $matchedVariation['price'] ?? $price }}" min="0.01" step="0.01"
                               class="form-control" >
                        <span class="error-text" data-error="price_{{ $str }}"></span>
                    </td>
                    <td>
                        <input type="number" name="stock_{{ $str }}" value="{{ $matchedVariation['stock'] ?? 0 }}" min="0" max="1000000"
                               class="form-control" onkeyup="update_qty()" >
                        <span class="error-text" data-error="stock_{{ $str }}"></span>
                    </td>
                </tr>
            @endif
        @endforeach
        </tbody>
    </table>
@endif
